@@ -1,5 +1,5 @@
 from .attrdict import AttrDict, KeyNotFound
-from ..compression import compress_list, decompress_list, COMPRESS_BEST
+from ..compression import compress_list, decompress_list, COMPRESS_FASTEST
 
 
 class EmptyKey(Exception):
@@ -98,6 +98,12 @@ class DefaultDict(AttrDict):
     def __bool__(self):
         return self._current_params().__bool__()
 
+    def __call__(self, data):
+        assert isinstance(data, bytes)
+        self.clear()
+        self.from_buffer(data)
+        return self
+
     def get(self, k):
         return self.__getitem__(k)
 
@@ -154,7 +160,7 @@ class DefaultDict(AttrDict):
         This compress all values of dict. Ref: "to_array"
         :return:
         """
-        return compress_list(self.to_array(), compress_type=COMPRESS_BEST)
+        return compress_list(self.to_array(), compress_type=COMPRESS_FASTEST)
 
     def from_buffer(self, buffer):
         """
@@ -167,7 +173,7 @@ class DefaultDict(AttrDict):
         self.from_array(decompress_list(buffer))
         return self
 
-    def to_buffer(self, compress_type=COMPRESS_BEST):
+    def to_buffer(self, compress_type=COMPRESS_FASTEST):
         return compress_list(self.to_array(), compress_type=compress_type)
 
     def setdefault(self, k, v=None, **kwargs):
