@@ -22,7 +22,7 @@ LOW_QUALITY = 60
 THUMBNAIL_QUALITY = 30
 
 IMTYPE_DEFAULT = cv2.IMREAD_ANYCOLOR
-INTER_DEFAULT = cv2.INTER_CUBIC
+INTER_DEFAULT = cv2.INTER_AREA
 
 ENCODE_JPEG = ".jpg"
 ENCODE_PNG = ".png"
